//==============================================================================
//	File:		$URL: svn+ssh://repositorypub@repository.eecs.berkeley.edu/public/Projects/GateLib/branches/dev/Platforms/ML505/Hardware/FPGA_TOP_ML505.v $
//	Version:	$Revision: 17012 $
//	Author:		Greg Gibeling (http://www.eecs.berkeley.edu/~gdgib/)
//	Copyright:	Copyright 2005-2008 UC Berkeley
//==============================================================================

//==============================================================================
//	Section:	License
//==============================================================================
//	Copyright (c) 2005-2008, Regents of the University of California
//	All rights reserved.
//
//	Redistribution and use in source and binary forms, with or without modification,
//	are permitted provided that the following conditions are met:
//
//		- Redistributions of source code must retain the above copyright notice,
//			this list of conditions and the following disclaimer.
//		- Redistributions in binary form must reproduce the above copyright
//			notice, this list of conditions and the following disclaimer
//			in the documentation and/or other materials provided with the
//			distribution.
//		- Neither the name of the University of California, Berkeley nor the
//			names of its contributors may be used to endorse or promote
//			products derived from this software without specific prior
//			written permission.
//
//	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
//	ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
//	ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
//	ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//==============================================================================

//------------------------------------------------------------------------------
//	Section:	Includes
//------------------------------------------------------------------------------
`include "Const.v"
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
//	Module:		FPGA_TOP_ML505
//	Desc:		Top level interface from a Xilinx XC5VLX50T or XC5VLX110T FPGA
//				to the ML505-50 or ML505-110 Board respectively.
//	Author:		<a href="http://gdgib.gotdns.com/~gdgib/">Greg Gibeling</a>
//	Version:	$Revision: 17012 $
//------------------------------------------------------------------------------
module FPGA_TOP_ML505(
			//------------------------------------------------------------------
			//	Compass Switches & LEDs
			//------------------------------------------------------------------
			GPIO_COMPLED,	// OUT(5b), W4, S3, N2, E1, C0
			GPIO_COMPSW,	// IN(5b), W4, S3, N2, E1, C0
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	 General IO (Dipswitch, LED, Rotary Encoder & Bus Error LEDs)
			//------------------------------------------------------------------
			GPIO_DIP,
			GPIO_LED,
	
			FPGA_ROTARY_INCA,
			FPGA_ROTARY_INCB,
			FPGA_ROTARY_PUSH,

			BUS_ERROR_1,
			BUS_ERROR_2,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	Clocks
			//------------------------------------------------------------------
			CLK_27MHZ_FPGA,
			CLK_33MHZ_FPGA,

			CLK_FPGA_N,
			CLK_FPGA_P,

			CLKBUF_Q1_N,
			CLKBUF_Q1_P,

			USER_CLK_100MHZ,

			FPGA_DIFF_CLK_OUT_N,
			FPGA_DIFF_CLK_OUT_P,

			SMA_DIFF_CLK_IN_N,
			SMA_DIFF_CLK_IN_P,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	Serial Ports
			//------------------------------------------------------------------
			FPGA_SERIAL_RX,
			FPGA_SERIAL_TX,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	Audio (AC97 & Piezo)
			//------------------------------------------------------------------
			//	Note that the reset is in with the FLASH memory signals (shared)
			AUDIO_BIT_CLK,
			AUDIO_SDATA_IN,
			AUDIO_SDATA_OUT,
			AUDIO_SYNC,
	
			PIEZO_SPEAKER,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	DRAM (DDR2 SODIMM)
			//------------------------------------------------------------------
			DDR2_CAS_B,
			DDR2_CKE,
			DDR2_RAS_B,
			DDR2_WE_B,
			DDR2_ODT,
			DDR2_CS0_B,

			DDR2_CLK_N,
			DDR2_CLK_P,

			DDR2_A,
			DDR2_BA,

			DDR2_DQ,
			DDR2_DM,
			DDR2_DQS_N,
			DDR2_DQS_P,

			I2C_DDR2_SCL,
			I2C_DDR2_SDA,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	PS/2 Ports
			//------------------------------------------------------------------
			KEYBOARD_CLK,
			KEYBOARD_DATA,
			MOUSE_CLK,
			MOUSE_DATA,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	LCD (16x2)
			//------------------------------------------------------------------
			LCD_FPGA_DB,
			LCD_FPGA_E,
			LCD_FPGA_RS,
			LCD_FPGA_RW,
			//------------------------------------------------------------------
		
			//------------------------------------------------------------------
			//	DVI Video
			//------------------------------------------------------------------
			DVI_D,

			DVI_DE,
			DVI_GPIO1,
			DVI_H,
			DVI_RESET_B,
			DVI_V,
			DVI_XCLK_N,
			DVI_XCLK_P,

			I2C_SCL_DVI,
			I2C_SDA_DVI,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	FPGA Configuration & Management
			//------------------------------------------------------------------
			SPI_CE_B,
	
			FPGA_CPU_RESET_B,
			FPGA_CS0_B,
	
			FPGA_VRN_B11,
			FPGA_VRN_B13,
			FPGA_VRN_B17,
			FPGA_VRN_B19,
			FPGA_VRN_B20,
			FPGA_VRN_B21,
			FPGA_VRN_B22,
			FPGA_VRP_B11,
			FPGA_VRP_B13,
			FPGA_VRP_B17,
			FPGA_VRP_B19,
			FPGA_VRP_B20,
			FPGA_VRP_B21,
			FPGA_VRP_B22,
	
			CFG_ADDR_OUT0,
			CFG_ADDR_OUT1,
	
			CPLD_IO_1,

			CPU_TCK,
			CPU_TDO,
			CPU_TMS,
			CPU_TRST,

			PC4_HALT_B,
			//------------------------------------------------------------------
		
			//------------------------------------------------------------------
			//	Headers
			//------------------------------------------------------------------
			HDR1,
			HDR2, 	// Also used for system management functions
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Main I2C: EEPROM, FAN, XGI
			//------------------------------------------------------------------
			I2C_SCL_MAIN,
			I2C_SDA_MAIN,
			FAN_ALERT_B,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Bank 118 GTPS: PCIe & Loopback
			//------------------------------------------------------------------
			PCIE_CLK_QO_N,
			PCIE_CLK_QO_P,

			PCIE_RX_N,
			PCIE_RX_P,
			PCIE_TX_N,
			PCIE_TX_P,
			PCIE_PRSNT_B_FPGA,

			LOOPBK_118_RX_N,
			LOOPBK_118_TX_N,
			LOOPBK_118_RX_P,
			LOOPBK_118_TX_P,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Ethernet PHY (non-SGMII)
			//------------------------------------------------------------------
			PHY_COL,
			PHY_CRS,
			PHY_INT,
			PHY_MDC,
			PHY_MDIO,
			PHY_RESET,
			
			PHY_RXCLK,
			PHY_RXCTL_RXDV,
			PHY_RXER,
			PHY_RXD,
			
			PHY_TXC_GTXCLK,
			PHY_TXCLK,
			PHY_TXCTL_TXEN,
			PHY_TXER,
			PHY_TXD,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Bank 116 GTPs: Small Form-Factor Pluggable & SMA
			//------------------------------------------------------------------
			CLKBUF_Q0_N,
			CLKBUF_Q0_P,

			SFP_RX_N,
			SFP_RX_P,
			SFP_TX_DISABLE_FPGA,
			SFP_TX_N,
			SFP_TX_P,

			I2C_SCL_SFP,
			I2C_SDA_SFP,

			SMA_RX_N,
			SMA_RX_P,
			SMA_TX_N,
			SMA_TX_P,
			//------------------------------------------------------------------
	
			//------------------------------------------------------------------
			//	Bank 112 GTPs: SGMII & Loopback
			//------------------------------------------------------------------
			SGMIICLK_QO_N,
			SGMIICLK_QO_P,
			
			SGMII_RX_N,
			SGMII_RX_P,
			SGMII_TX_N,
			SGMII_TX_P,

			LOOPBK_112_RX_N,
			LOOPBK_112_TX_N,
			LOOPBK_112_RX_P,
			LOOPBK_112_TX_P,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Bank 114 GTPs: SATA Connectors
			//------------------------------------------------------------------
			SATACLK_QO_N,
			SATACLK_QO_P,
			
			SATA_RX_N,
			SATA_RX_P,
			SATA_TX_N,
			SATA_TX_P,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	ZBT SRAM & Linear Flash Memory
			//------------------------------------------------------------------
			SRAM_CLK,
			SRAM_CLK_FB,
			SRAM_CS_B,
			SRAM_ADV_LD_B,
			
			SRAM_FLASH_WE_B,
			SRAM_MODE,
			SRAM_OE_B,
			
			FLASH_ADV_B,
			FLASH_AUDIO_RESET_B,
			FLASH_CE_B,
			FLASH_CLK,
			FLASH_OE_B,
			FLASH_WAIT,
			
			SRAM_BW,

			SRAM_DQP,

			SRAM_FLASH_A,
			SRAM_FLASH_D,
			SRAM_D,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	System ACE & Cypress USB
			//------------------------------------------------------------------
			SYSACE_MPA,

			SYSACE_MPBRDY,
			SYSACE_MPCE,
			SYSACE_MPIRQ,
			SYSACE_MPOE_USB_RD_B,
			SYSACE_MPWE_USB_WR_B,

			SYSACE_USB_D,

			USB_A,
			USB_CS_B,
			USB_INT,
			USB_RESET_B,
			//------------------------------------------------------------------

			//------------------------------------------------------------------
			//	Tracing
			//------------------------------------------------------------------
			TRC_CLK,
			TRC_TS1E,
			TRC_TS1O,
			TRC_TS2E,
			TRC_TS2O,
			TRC_TS3,
			TRC_TS4,
			TRC_TS5,
			TRC_TS6,
			//------------------------------------------------------------------


			//------------------------------------------------------------------
			//	VGA (Input)
			//------------------------------------------------------------------
			VGA_IN_BLUE,
			VGA_IN_GREEN,
			VGA_IN_RED,

			VGA_IN_CLAMP,
			VGA_IN_COAST,
			VGA_IN_DATA_CLK,
			VGA_IN_HSOUT,
			VGA_IN_ODD_EVEN_B,
			VGA_IN_SOGOUT,
			VGA_IN_VSOUT
			//------------------------------------------------------------------
		); /* synthesis syn_noprune=1 */
	//--------------------------------------------------------------------------
	//	Compass Switches & LEDs (W4, S3, N2, E1, C0)
	//--------------------------------------------------------------------------
	output	[4:0]			GPIO_COMPLED 			/* synthesis xc_loc = "AF23,AG12,AF13,AG23,E8" xc_padtype = "OBUF_LVCMOS33_S_2" xc_pulldown = 1 chip_pin = "AF23,AG12,AF13,AG23,E8" altera_attribute="-name IO_STANDARD LVCMOS33_S_2" */;
	// synthesis attribute LOC of					GPIO_COMPLED is			"AF23,AG12,AF13,AG23,E8"
	// synthesis attribute IOSTANDARD of			GPIO_COMPLED is			"LVCMOS33"
	// synthesis attribute SLEW of					GPIO_COMPLED is			"SLOW"
	// synthesis attribute DRIVE of					GPIO_COMPLED is			"2"
	input	[4:0]			GPIO_COMPSW				/* synthesis xc_loc = "AJ7,V8,U8,AK7,AJ6" xc_padtype = "IBUF_LVCMOS33" xc_pulldown = 1 chip_pin = "AJ7,V8,U8,AK7,AJ6" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					GPIO_COMPSW is			"AJ7,V8,U8,AK7,AJ6"
	// synthesis attribute IOSTANDARD of			GPIO_COMPSW is			"LVCMOS33"
	
	genvar			i;
	`ifdef PULL
		generate for (i = 0; i < 5; i = i + 1) begin:PULL_GPIO_COMPXXX
			pulldown(GPIO_COMPLED[i]);
			pulldown(GPIO_COMPSW[i]);
		end endgenerate
	`endif
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	 General IO (Dipswitch, LED, Rotary Encoder & Bus Error LEDs)
	//--------------------------------------------------------------------------
	input	[7:0]			GPIO_DIP				/* synthesis xc_loc = "AC24,AC25,AE26,AE27,AF26,AF25,AG27,U25" xc_padtype = "IBUF_LVCMOS25" chip_pin = "AC24,AC25,AE26,AE27,AF26,AF25,AG27,U25" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					GPIO_DIP is				"AC24,AC25,AE26,AE27,AF26,AF25,AG27,U25"
	// synthesis attribute IOSTANDARD of			GPIO_DIP is				"LVCMOS25"
	output	[7:0]			GPIO_LED				/* synthesis xc_loc = "AE24,AD24,AD25,G16,AD26,G15,L18,H18" xc_padtype = "OBUF_LVCMOS25_S_2" xc_pulldown = 1 chip_pin = "AE24,AD24,AD25,G16,AD26,G15,L18,H18" altera_attribute="-name IO_STANDARD LVCMOS25_S_2" */;
	// synthesis attribute LOC of					GPIO_LED is				"AE24,AD24,AD25,G16,AD26,G15,L18,H18"
	// synthesis attribute IOSTANDARD of			GPIO_LED is				"LVCMOS25"
	// synthesis attribute SLEW of					GPIO_LED is				"SLOW"
	// synthesis attribute DRIVE of					GPIO_LED is				"2"
	
	`ifdef PULL
		generate for (i = 0; i < 8; i = i + 1) begin:PULL_GPIO_XXX
			pulldown(GPIO_DIP[i]);
			pulldown(GPIO_LED[i]);
		end endgenerate
	`endif
	
	input					FPGA_ROTARY_INCA		/* synthesis xc_loc = "AH30" chip_pin = "AH30" */;
	// synthesis attribute LOC of					FPGA_ROTARY_INCA is		"AH30"
	input					FPGA_ROTARY_INCB		/* synthesis xc_loc = "AG30" chip_pin = "AG30" */;
	// synthesis attribute LOC of					FPGA_ROTARY_INCB is		"AG30"
	input					FPGA_ROTARY_PUSH		/* synthesis xc_loc = "AH29" chip_pin = "AH29" */;
	// synthesis attribute LOC of					FPGA_ROTARY_PUSH is		"AH29"

	output					BUS_ERROR_1				/* synthesis xc_loc = "F6" chip_pin = "F6" */;
	// synthesis attribute LOC of					BUS_ERROR_1 is			"F6"
	output					BUS_ERROR_2				/* synthesis xc_loc = "T10" chip_pin = "T10" */;
	// synthesis attribute LOC of					BUS_ERROR_2 is			"T10"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Clocks
	//--------------------------------------------------------------------------
	input					CLK_27MHZ_FPGA			/* synthesis xc_loc = "AG18" xc_padtype="IBUF_LVCMOS33" chip_pin = "AG18" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					CLK_27MHZ_FPGA is		"AG18"
	// synthesis attribute IOSTANDARD of			CLK_27MHZ_FPGA is		"LVCMOS33"
	// synthesis attribute PERIOD of 				CLK_27MHZ_FPGA is		"27 MHz"
	input					CLK_33MHZ_FPGA			/* synthesis xc_loc = "AH17" xc_padtype="IBUF_LVCMOS33" chip_pin = "AH17" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					CLK_33MHZ_FPGA is		"AH17"
	// synthesis attribute IOSTANDARD of			CLK_33MHZ_FPGA is		"LVCMOS33"
	// synthesis attribute PERIOD of 				CLK_33MHZ_FPGA is		"33 MHz"

	input					CLK_FPGA_N				/* synthesis xc_loc = "K19" chip_pin = "K19" */;
	// synthesis attribute LOC of					CLK_FPGA_N is			"K19"
	input					CLK_FPGA_P				/* synthesis xc_loc = "L19" chip_pin = "L19" */;
	// synthesis attribute LOC of					CLK_FPGA_P is			"L19"

	input					CLKBUF_Q1_N				/* synthesis xc_loc = "J19" chip_pin = "J19" */;
	// synthesis attribute LOC of					CLKBUF_Q1_N is			"J19"
	// synthesis attribute PERIOD of 				CLKBUF_Q1_N is			"200 MHz"
	input					CLKBUF_Q1_P				/* synthesis xc_loc = "K18" chip_pin = "K18" */;
	// synthesis attribute LOC of					CLKBUF_Q1_P is			"K18"
	// synthesis attribute PERIOD of 				CLKBUF_Q1_P is			"200 MHz"

	input					USER_CLK_100MHZ			/* synthesis xc_loc = "AH15" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AH15" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					USER_CLK_100MHZ is		"AH15"
	// synthesis attribute IOSTANDARD of			USER_CLK_100MHZ is		"LVCMOS33"
	// synthesis attribute PERIOD of 				USER_CLK_100MHZ is		"100 MHz"

	output					FPGA_DIFF_CLK_OUT_N		/* synthesis xc_loc = "J21" chip_pin = "J21" */;
	// synthesis attribute LOC of					FPGA_DIFF_CLK_OUT_N is	"J21"
	output					FPGA_DIFF_CLK_OUT_P		/* synthesis xc_loc = "J20" chip_pin = "J20" */;
	// synthesis attribute LOC of					FPGA_DIFF_CLK_OUT_P is	"J20"

	input					SMA_DIFF_CLK_IN_N		/* synthesis xc_loc = "H15" chip_pin = "H15" */;
	// synthesis attribute LOC of					SMA_DIFF_CLK_IN_N is	"H15"
	input					SMA_DIFF_CLK_IN_P		/* synthesis xc_loc = "H14" chip_pin = "H14" */;
	// synthesis attribute LOC of					SMA_DIFF_CLK_IN_P is	"H14"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Serial Ports
	//--------------------------------------------------------------------------
	input	[2:1]			FPGA_SERIAL_RX			/* synthesis xc_loc = "G10,AG15" xc_padtype = "IBUF_LVCMOS33" chip_pin = "G10,AG15" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FPGA_SERIAL_RX is		"G10,AG15"
	// synthesis attribute IOSTANDARD of			FPGA_SERIAL_RX is		"LVCMOS33"
	output	[2:1]			FPGA_SERIAL_TX			/* synthesis xc_loc = "F10,AG20" xc_padtype = "OBUF_LVCMOS33" chip_pin = "F10,AG20" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FPGA_SERIAL_TX is		"F10,AG20"
	// synthesis attribute IOSTANDARD of			FPGA_SERIAL_TX is		"LVCMOS33"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Audio (AC97 & Piezo)
	//--------------------------------------------------------------------------
	//	Note that the reset is in with the FLASH memory signals (shared)
	output					AUDIO_BIT_CLK			/* synthesis xc_loc = "AF18" chip_pin = "AF18" */;
	// synthesis attribute LOC of					AUDIO_BIT_CLK is		"AF18"
	input					AUDIO_SDATA_IN			/* synthesis xc_loc = "AE18" chip_pin = "AE18" */;
	// synthesis attribute LOC of					AUDIO_SDATA_IN is		"AE18"
	output					AUDIO_SDATA_OUT			/* synthesis xc_loc = "AG16" chip_pin = "AG16" */;
	// synthesis attribute LOC of					AUDIO_SDATA_OUT is		"AG16"
	output					AUDIO_SYNC				/* synthesis xc_loc = "AF19" chip_pin = "AF19" */;
	// synthesis attribute LOC of					AUDIO_SYNC is			"AF19"
	
	output					PIEZO_SPEAKER			/* synthesis xc_loc = "G30" chip_pin = "G30" */;
	// synthesis attribute LOC of					PIEZO_SPEAKER is		"G30"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	DRAM (DDR2 SODIMM)
	//--------------------------------------------------------------------------
	output					DDR2_CAS_B				/* synthesis xc_loc = "E31" xc_padtype="OBUF_SSTL18_II" chip_pin = "E31" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_CAS_B is			"E31"
	// synthesis attribute IOSTANDARD of			DDR2_CAS_B is			"SSTL18_II"
	output	[1:0]			DDR2_CKE				/* synthesis xc_loc = "U30,T28" xc_padtype="OBUF_SSTL18_II" chip_pin = "U30,T28" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_CKE is				"U30,T28"
	// synthesis attribute IOSTANDARD of			DDR2_CKE is				"SSTL18_II"
	output					DDR2_RAS_B				/* synthesis xc_loc = "H30" xc_padtype="OBUF_SSTL18_II" chip_pin = "H30" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_RAS_B is			"H30"
	// synthesis attribute IOSTANDARD of			DDR2_RAS_B is			"SSTL18_II"
	output					DDR2_WE_B				/* synthesis xc_loc = "K29" xc_padtype="OBUF_SSTL18_II" chip_pin = "K29" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_WE_B is			"K29"
	// synthesis attribute IOSTANDARD of			DDR2_WE_B is			"SSTL18_II"
	output	[1:0]			DDR2_ODT				/* synthesis xc_loc = "F30,F31" xc_padtype="OBUF_SSTL18_II" chip_pin = "F30,F31" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_ODT is				"F30,F31"
	// synthesis attribute IOSTANDARD of			DDR2_ODT is				"SSTL18_II"
	output	[1:0]			DDR2_CS0_B				/* synthesis xc_loc = "J29,L29" xc_padtype="OBUF_SSTL18_II" chip_pin = "J29,L29" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_CS0_B is			"J29,L29"
	// synthesis attribute IOSTANDARD of			DDR2_CS0_B is			"SSTL18_II"

	output	[1:0]			DDR2_CLK_N				/* synthesis xc_loc = "F28,AJ29" xc_padtype="OBUF_DIFF_SSTL18_II" chip_pin = "F28,AJ29" altera_attribute="-name IO_STANDARD DIFF_SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_CLK_N is			"F28,AJ29"
	// synthesis attribute IOSTANDARD of			DDR2_CLK_N is			"DIFF_SSTL18_II"
	output	[1:0]			DDR2_CLK_P				/* synthesis xc_loc = "E28,AK29" xc_padtype="OBUF_DIFF_SSTL18_II" chip_pin = "E28,AK29" altera_attribute="-name IO_STANDARD DIFF_SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_CLK_P is			"E28,AK29"
	// synthesis attribute IOSTANDARD of			DDR2_CLK_P is			"DIFF_SSTL18_II"

	output	[13:0]			DDR2_A					/* synthesis xc_loc = "H29,T31,R29,J31,R28,M31,P30,P31,L31,K31,P29,N29,M30,L30" xc_padtype="OBUF_SSTL18_II" chip_pin = "H29,T31,R29,J31,R28,M31,P30,P31,L31,K31,P29,N29,M30,L30" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_A is				"H29,T31,R29,J31,R28,M31,P30,P31,L31,K31,P29,N29,M30,L30"
	// synthesis attribute IOSTANDARD of			DDR2_A is				"SSTL18_II"
	output	[2:0]			DDR2_BA					/* synthesis xc_loc = "R31,J30,G31" xc_padtype="OBUF_SSTL18_II" chip_pin = "R31,J30,G31" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_BA is				"R31,J30,G31"
	// synthesis attribute IOSTANDARD of			DDR2_BA is				"SSTL18_II"

	inout	[63:0]			DDR2_DQ					/* synthesis xc_loc = "L24,L25,M25,J27,L26,J24,M26,G25,G26,H24,K28,K27,H25,F25,L28,M28,N28,P27,N25,T24,P26,N24,P25,R24,V24,W26,W25,V28,W24,Y26,Y27,V29,W27,V27,W29,AC30,V30,W31,AB30,AC29,AA25,AB27,AA24,AB26,AA26,AC27,AB25,AC28,AB28,AG28,AJ26,AG25,AA28,AH28,AF28,AH27,AE29,AD29,AF29,AJ30,AD30,AF31,AK31,AF30" xc_padtype="IOBUF_SSTL18_II_DCI" chip_pin = "L24,L25,M25,J27,L26,J24,M26,G25,G26,H24,K28,K27,H25,F25,L28,M28,N28,P27,N25,T24,P26,N24,P25,R24,V24,W26,W25,V28,W24,Y26,Y27,V29,W27,V27,W29,AC30,V30,W31,AB30,AC29,AA25,AB27,AA24,AB26,AA26,AC27,AB25,AC28,AB28,AG28,AJ26,AG25,AA28,AH28,AF28,AH27,AE29,AD29,AF29,AJ30,AD30,AF31,AK31,AF30" altera_attribute="-name IO_STANDARD SSTL18_II_DCI" */;
	// synthesis attribute LOC of					DDR2_DQ is				"L24,L25,M25,J27,L26,J24,M26,G25,G26,H24,K28,K27,H25,F25,L28,M28,N28,P27,N25,T24,P26,N24,P25,R24,V24,W26,W25,V28,W24,Y26,Y27,V29,W27,V27,W29,AC30,V30,W31,AB30,AC29,AA25,AB27,AA24,AB26,AA26,AC27,AB25,AC28,AB28,AG28,AJ26,AG25,AA28,AH28,AF28,AH27,AE29,AD29,AF29,AJ30,AD30,AF31,AK31,AF30"
	// synthesis attribute IOSTANDARD of			DDR2_DQ is				"SSTL18_II_DCI"
	output	[7:0]			DDR2_DM					/* synthesis xc_loc = "J25,F26,P24,V25,Y31,Y24,AE28,AJ31" xc_padtype="OBUF_SSTL18_II" chip_pin = "J25,F26,P24,V25,Y31,Y24,AE28,AJ31" altera_attribute="-name IO_STANDARD SSTL18_II" */;
	// synthesis attribute LOC of					DDR2_DM is				"J25,F26,P24,V25,Y31,Y24,AE28,AJ31"
	// synthesis attribute IOSTANDARD of			DDR2_DM is				"SSTL18_II"
	inout	[7:0]			DDR2_DQS_N				/* synthesis xc_loc = "H27,G28,E27,Y29,AA31,AJ27,AK27,AA30" xc_padtype="IOBUF_DIFF_SSTL18_II_DCI" chip_pin = "H27,G28,E27,Y29,AA31,AJ27,AK27,AA30" altera_attribute="-name IO_STANDARD DIFF_SSTL18_II_DCI" */;
	// synthesis attribute LOC of					DDR2_DQS_N is			"H27,G28,E27,Y29,AA31,AJ27,AK27,AA30"
	// synthesis attribute IOSTANDARD of			DDR2_DQS_N is			"DIFF_SSTL18_II_DCI"
	inout	[7:0]			DDR2_DQS_P				/* synthesis xc_loc = "G27,H28,E26,Y28,AB31,AK26,AK28,AA29" xc_padtype="IOBUF_DIFF_SSTL18_II_DCI" chip_pin = "G27,H28,E26,Y28,AB31,AK26,AK28,AA29" altera_attribute="-name IO_STANDARD DIFF_SSTL18_II_DCI" */;
	// synthesis attribute LOC of					DDR2_DQS_P is			"G27,H28,E26,Y28,AB31,AK26,AK28,AA29"
	// synthesis attribute IOSTANDARD of			DDR2_DQS_P is			"DIFF_SSTL18_II_DCI"

	inout					I2C_DDR2_SCL			/* synthesis xc_loc = "E29" chip_pin = "E29" */;
	// synthesis attribute LOC of					DDR2_SCL is				"E29"
	inout					I2C_DDR2_SDA			/* synthesis xc_loc = "F29" chip_pin = "F29" */;
	// synthesis attribute LOC of					DDR2_SDA is				"F29"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	PS/2 Ports
	//--------------------------------------------------------------------------
	inout					KEYBOARD_CLK			/* synthesis xc_loc = "T26" chip_pin = "T26" */;
	// synthesis attribute LOC of					KEYBOARD_CLK is			"T26"
	inout					KEYBOARD_DATA			/* synthesis xc_loc = "T25" chip_pin = "T25" */;
	// synthesis attribute LOC of					KEYBOARD_DATA is		"T25"
	inout					MOUSE_CLK				/* synthesis xc_loc = "R27" chip_pin = "R27" */;
	// synthesis attribute LOC of					MOUSE_CLK is			"R27"
	inout					MOUSE_DATA				/* synthesis xc_loc = "U26" chip_pin = "U26" */;
	// synthesis attribute LOC of					MOUSE_DATA is			"U26"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	LCD (16x2)
	//--------------------------------------------------------------------------
	inout	[7:4]			LCD_FPGA_DB				/* synthesis xc_loc = "T11,G6,G7,T9" chip_pin = "T11,G6,G7,T9" */;
	// synthesis attribute LOC of					LCD_FPGA_DB is			"T11,G6,G7,T9"
	output					LCD_FPGA_E				/* synthesis xc_loc = "AC9" chip_pin = "AC9" */;
	// synthesis attribute LOC of					LCD_FPGA_E is			"AC9"
	output					LCD_FPGA_RS				/* synthesis xc_loc = "J17" chip_pin = "J17" */;
	// synthesis attribute LOC of					LCD_FPGA_RS is			"J17"
	output					LCD_FPGA_RW				/* synthesis xc_loc = "AC10" chip_pin = "AC10" */;
	// synthesis attribute LOC of					LCD_FPGA_RW is			"AC10"
	//--------------------------------------------------------------------------
		
	//--------------------------------------------------------------------------
	//	DVI Video
	//--------------------------------------------------------------------------
	output	[11:0]			DVI_D					/* synthesis xc_loc = "AN14,AP14,AB10,AA10,AN13,AM13,AA8,AA9,AP12,AN12,AC8,AB8" chip_pin = "AN14,AP14,AB10,AA10,AN13,AM13,AA8,AA9,AP12,AN12,AC8,AB8" */;
	// synthesis attribute LOC of					DVI_D is				"AN14,AP14,AB10,AA10,AN13,AM13,AA8,AA9,AP12,AN12,AC8,AB8"

	output					DVI_DE					/* synthesis xc_loc = "AE8" chip_pin = "AE8" */;
	// synthesis attribute LOC of					DVI_DE is				"AE8"
	output					DVI_GPIO1				/* synthesis xc_loc = "N30" chip_pin = "N30" */;
	// synthesis attribute LOC of					DVI_GPIO1 is			"N30"
	output					DVI_H					/* synthesis xc_loc = "AM12" chip_pin = "AM12" */;
	// synthesis attribute LOC of					DVI_H is				"AM12"
	output					DVI_RESET_B				/* synthesis xc_loc = "AK6" xc_padtype = "OBUF_LVCMOS33" chip_pin = "AK6" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					DVI_RESET_B is			"AK6"
	// synthesis attribute IOSTANDARD of			DVI_RESET_B is			"LVCMOS33"
	output					DVI_V					/* synthesis xc_loc = "AM11" chip_pin = "AM11" */;
	// synthesis attribute LOC of					DVI_V is				"AM11"
	output					DVI_XCLK_N				/* synthesis xc_loc = "AL10" chip_pin = "AL10" */;
	// synthesis attribute LOC of					DVI_XCLK_N is			"AL10"
	output					DVI_XCLK_P				/* synthesis xc_loc = "AL11" chip_pin = "AL11" */;
	// synthesis attribute LOC of					DVI_XCLK_P is			"AL11"

	inout					I2C_SCL_DVI				/* synthesis xc_loc = "U27" chip_pin = "U27" */;
	// synthesis attribute LOC of					I2C_SCL_DVI is			"U27"
	inout					I2C_SDA_DVI				/* synthesis xc_loc = "T29" chip_pin = "T29" */;
	// synthesis attribute LOC of					I2C_SDA_DVI is			"T29"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	FPGA Configuration & Management
	//--------------------------------------------------------------------------
	inout					SPI_CE_B				/* synthesis xc_loc = "V9" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "V9" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SPI_CE_B is				"V9"
	// synthesis attribute IOSTANDARD of			SPI_CE_B is				"LVCMOS33"
	
	input					FPGA_CPU_RESET_B		/* synthesis xc_loc = "E9" xc_padtype = "IBUF_LVCMOS33" xc_pullup = 1 chip_pin = "E9" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FPGA_CPU_RESET_B is		"E9"
	// synthesis attribute IOSTANDARD of			FPGA_CPU_RESET_B is		"LVCMOS33"
	`ifdef PULL
		pullup(FPGA_CPU_RESET_B);
	`endif
	inout					FPGA_CS0_B				/* synthesis xc_loc = "AF21" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "AF21" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FPGA_CS0_B is			"AF21"
	// synthesis attribute IOSTANDARD of			FPGA_CS0_B is			"LVCMOS33"
	
	inout					FPGA_VRN_B11			/* synthesis xc_loc = "N33" chip_pin = "N33" */;
	// synthesis attribute LOC of					FPGA_VRN_B11 is			"N33"
	inout					FPGA_VRN_B13			/* synthesis xc_loc = "AG33" chip_pin = "AG33" */;
	// synthesis attribute LOC of					FPGA_VRN_B13 is			"AG33"
	inout					FPGA_VRN_B17			/* synthesis xc_loc = "AD31" chip_pin = "AD31" */;
	// synthesis attribute LOC of					FPGA_VRN_B17 is			"AD31"
	inout					FPGA_VRN_B19			/* synthesis xc_loc = "N27" chip_pin = "N27" */;
	// synthesis attribute LOC of					FPGA_VRN_B19 is			"N27"
	inout					FPGA_VRN_B20			/* synthesis xc_loc = "L10" chip_pin = "L10" */;
	// synthesis attribute LOC of					FPGA_VRN_B20 is			"L10"
	inout					FPGA_VRN_B21			/* synthesis xc_loc = "AJ25" chip_pin = "AJ25" */;
	// synthesis attribute LOC of					FPGA_VRN_B21 is			"AJ25"
	inout					FPGA_VRN_B22			/* synthesis xc_loc = "AF8" chip_pin = "AF8" */;
	// synthesis attribute LOC of					FPGA_VRN_B22 is			"AF8"
	inout					FPGA_VRP_B11			/* synthesis xc_loc = "M33" chip_pin = "M33" */;
	// synthesis attribute LOC of					FPGA_VRP_B11 is			"M33"
	inout					FPGA_VRP_B13			/* synthesis xc_loc = "AH33" chip_pin = "AH33" */;
	// synthesis attribute LOC of					FPGA_VRP_B13 is			"AH33"
	inout					FPGA_VRP_B17			/* synthesis xc_loc = "AE31" chip_pin = "AE31" */;
	// synthesis attribute LOC of					FPGA_VRP_B17 is			"AE31"
	inout					FPGA_VRP_B19			/* synthesis xc_loc = "M27" chip_pin = "M27" */;
	// synthesis attribute LOC of					FPGA_VRP_B19 is			"M27"
	inout					FPGA_VRP_B20			/* synthesis xc_loc = "L11" chip_pin = "L11" */;
	// synthesis attribute LOC of					FPGA_VRP_B20 is			"L11"
	inout					FPGA_VRP_B21			/* synthesis xc_loc = "AH25" chip_pin = "AH25" */;
	// synthesis attribute LOC of					FPGA_VRP_B21 is			"AH25"
	inout					FPGA_VRP_B22			/* synthesis xc_loc = "AE9" chip_pin = "AE9" */;
	// synthesis attribute LOC of					FPGA_VRP_B22 is			"AE9"
	
	inout					CFG_ADDR_OUT0			/* synthesis xc_loc = "AE12" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "AE12" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					CFG_ADDR_OUT0 is		"AE12"
	// synthesis attribute IOSTANDARD of			CFG_ADDR_OUT0 is		"LVCMOS33"
	inout					CFG_ADDR_OUT1			/* synthesis xc_loc = "AE13" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "AE13" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					CFG_ADDR_OUT1 is		"AE13"
	// synthesis attribute IOSTANDARD of			CFG_ADDR_OUT1 is		"LVCMOS33"
	
	inout					CPLD_IO_1				/* synthesis xc_loc = "W10" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "W10" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					CPLD_IO_1 is			"W10"
	// synthesis attribute IOSTANDARD of			CPLD_IO_1 is			"LVCMOS33"

	inout					CPU_TCK					/* synthesis xc_loc = "E6" chip_pin = "E6" */;
	// synthesis attribute LOC of					CPU_TCK is				"E6"
	inout					CPU_TDO					/* synthesis xc_loc = "E7" chip_pin = "E7" */;
	// synthesis attribute LOC of					CPU_TDO is				"E7"
	inout					CPU_TMS					/* synthesis xc_loc = "U10" chip_pin = "U10" */;
	// synthesis attribute LOC of					CPU_TMS is				"U10"
	inout					CPU_TRST				/* synthesis xc_loc = "V10" chip_pin = "V10" */;
	// synthesis attribute LOC of					CPU_TRST is				"V10"

	inout					PC4_HALT_B				/* synthesis xc_loc = "W9" xc_padtype = "IOBUF_LVCMOS33" chip_pin = "W9" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					PC4_HALT_B is			"W9"
	// synthesis attribute IOSTANDARD of			PC4_HALT_B is			"LVCMOS33"
	//--------------------------------------------------------------------------
		
	//--------------------------------------------------------------------------
	//	Headers
	//--------------------------------------------------------------------------
	// [64:2] no odd numbers....
	inout	[31:0]			HDR1					/* synthesis xc_loc = "AN33,AN34,AM32,AJ34,AM33,AL33,AL34,AK32,AJ32,AK33,AK34,AH32,AG32,AE32,AH34,W32,Y32,Y34,AD32,AA34,N34,P34,M32,L33,J34,J32,H32,G32,G33,H34,F34,H33" chip_pin = "AN33,AN34,AM32,AJ34,AM33,AL33,AL34,AK32,AJ32,AK33,AK34,AH32,AG32,AE32,AH34,W32,Y32,Y34,AD32,AA34,N34,P34,M32,L33,J34,J32,H32,G32,G33,H34,F34,H33" */;
	// synthesis attribute LOC of					HDR1 is					"AN33,AN34,AM32,AJ34,AM33,AL33,AL34,AK32,AJ32,AK33,AK34,AH32,AG32,AE32,AH34,W32,Y32,Y34,AD32,AA34,N34,P34,M32,L33,J34,J32,H32,G32,G33,H34,F34,H33"

	// [64:2] no odd numbers...
	// Also used for system management functions
	inout	[31:0]			HDR2					/* synthesis xc_loc = "AN32,AP32,AC33,AB33,AC32,AB32,AC34,AD34,AF33,AE33,AF34,AE34,Y33,AA33,W34,V34,V32,V33,U32,U31,U33,T34,R33,R32,T33,R34,P32,N32,K33,K32,L34,K34" chip_pin = "AN32,AP32,AC33,AB33,AC32,AB32,AC34,AD34,AF33,AE33,AF34,AE34,Y33,AA33,W34,V34,V32,V33,U32,U31,U33,T34,R33,R32,T33,R34,P32,N32,K33,K32,L34,K34" */;
	// synthesis attribute LOC of					HDR2 is					"AN32,AP32,AC33,AB33,AC32,AB32,AC34,AD34,AF33,AE33,AF34,AE34,Y33,AA33,W34,V34,V32,V33,U32,U31,U33,T34,R33,R32,T33,R34,P32,N32,K33,K32,L34,K34"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	Main I2C: EEPROM, FAN, XGI
	//--------------------------------------------------------------------------
	inout					I2C_SCL_MAIN			/* synthesis xc_loc = "F9" xc_padtype = "IOBUF_LVCMOS33_S_6" chip_pin = "F9" altera_attribute="-name IO_STANDARD LVCMOS33_S_6" */;
	// synthesis attribute LOC of					I2C_SCL_MAIN is			"F9"
	// synthesis attribute IOSTANDARD of			I2C_SCL_MAIN is			"LVCMOS33"
	// synthesis attribute SLEW of					I2C_SCL_MAIN is			"SLOW"
	// synthesis attribute DRIVE of					I2C_SCL_MAIN is			"6"
	inout					I2C_SDA_MAIN			/* synthesis xc_loc = "F8" xc_padtype = "IOBUF_LVCMOS33_S_6" chip_pin = "F8" altera_attribute="-name IO_STANDARD LVCMOS33_S_6" */;
	// synthesis attribute LOC of					I2C_SDA_MAIN is			"F8"
	// synthesis attribute IOSTANDARD of			I2C_SDA_MAIN is			"LVCMOS33"
	// synthesis attribute SLEW of					I2C_SDA_MAIN is			"SLOW"
	// synthesis attribute DRIVE of					I2C_SDA_MAIN is			"6"
	input					FAN_ALERT_B				/* synthesis xc_loc = "T30" chip_pin = "T30" */;
	// synthesis attribute LOC of					FAN_ALERT_B is			"T30"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	Bank 118 GTPS: PCIe & Loopback
	//--------------------------------------------------------------------------
	input					PCIE_CLK_QO_N			/* synthesis xc_loc = "AF3" chip_pin = "AF3" */;
	// synthesis attribute LOC of					PCIE_CLK_QO_N is		"AF3"
	input					PCIE_CLK_QO_P			/* synthesis xc_loc = "AF4" chip_pin = "AF4" */;
	// synthesis attribute LOC of					PCIE_CLK_QO_P is		"AF4"

	input					PCIE_RX_N				/* synthesis xc_loc = "AF1" chip_pin = "AF1" */;
	// synthesis attribute LOC of					PCIE_RX_N is			"AF1"
	input					PCIE_RX_P				/* synthesis xc_loc = "AE1" chip_pin = "AE1" */;
	// synthesis attribute LOC of					PCIE_RX_P is			"AE1"
	output					PCIE_TX_N				/* synthesis xc_loc = "AE2" chip_pin = "AE2" */;
	// synthesis attribute LOC of					PCIE_TX_N is			"AE2"
	output					PCIE_TX_P				/* synthesis xc_loc = "AD2" chip_pin = "AD2" */;
	// synthesis attribute LOC of					PCIE_TX_P is			"AD2"
	input					PCIE_PRSNT_B_FPGA		/* synthesis xc_loc = "AF24" chip_pin = "AF24" */;
	// synthesis attribute LOC of					PCIE_PRSNT_B_FPGA is	"AF24"

	input					LOOPBK_118_RX_N			/* synthesis xc_loc = "AG1" chip_pin = "AG1" */;
	// synthesis attribute LOC of					LOOPBK_118_RX_N is		"AG1"
	output					LOOPBK_118_TX_N			/* synthesis xc_loc = "AH2" chip_pin = "AH2" */;
	// synthesis attribute LOC of					LOOPBK_118_TX_N is		"AH2"
	input					LOOPBK_118_RX_P			/* synthesis xc_loc = "AH1" chip_pin = "AH1" */;
	// synthesis attribute LOC of					LOOPBK_118_RX_P is		"AH1"
	output					LOOPBK_118_TX_P			/* synthesis xc_loc = "AJ2" chip_pin = "AJ2" */;
	// synthesis attribute LOC of					LOOPBK_118_TX_P is		"AJ2"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	Ethernet PHY (non-SGMII)
	//--------------------------------------------------------------------------
	input					PHY_COL					/* synthesis xc_loc = "B32" xc_padtype = "IBUF_LVCMOS25" chip_pin = "B32" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_COL is				"B32"
	// synthesis attribute IOSTANDARD of			PHY_COL is				"LVCMOS25"
	input					PHY_CRS					/* synthesis xc_loc = "E34" xc_padtype = "IBUF_LVCMOS25" chip_pin = "E34" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_CRS is				"E34"
	// synthesis attribute IOSTANDARD of			PHY_CRS is				"LVCMOS25"
	input					PHY_INT					/* synthesis xc_loc = "H20" xc_padtype = "IBUF_LVCMOS25" chip_pin = "H20" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_INT is				"H20"
	// synthesis attribute IOSTANDARD of			PHY_INT is				"LVCMOS25"
	inout					PHY_MDC					/* synthesis xc_loc = "H19" xc_padtype = "IOBUF_LVCMOS25" chip_pin = "H19" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_MDC is				"H19"
	// synthesis attribute IOSTANDARD of			PHY_MDC is				"LVCMOS25"
	inout					PHY_MDIO				/* synthesis xc_loc = "H13" xc_padtype = "IOBUF_LVCMOS25" chip_pin = "H13" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_MDIO is				"H13"
	// synthesis attribute IOSTANDARD of			PHY_MDIO is				"LVCMOS25"
	output					PHY_RESET				/* synthesis xc_loc = "J14" xc_padtype = "OBUF_LVCMOS25" chip_pin = "J14" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_RESET is			"J14"
	// synthesis attribute IOSTANDARD of			PHY_RESET is			"LVCMOS25"
	
	input					PHY_RXCLK				/* synthesis xc_loc = "H17" xc_padtype = "IBUF_LVCMOS25" chip_pin = "H17" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_RXCLK is			"H17"
	// synthesis attribute IOSTANDARD of			PHY_RXCLK is			"LVCMOS25"
	// synthesis attribute PERIOD of				PHY_RXCLK is			"125 MHz"
	input					PHY_RXCTL_RXDV			/* synthesis xc_loc = "E32" xc_padtype = "IBUF_LVCMOS25" chip_pin = "E32" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_RXCTL_RXDV is		"E32"
	// synthesis attribute IOSTANDARD of			PHY_RXCTL_RXDV is		"LVCMOS25"
	input					PHY_RXER				/* synthesis xc_loc = "E33" xc_padtype = "IBUF_LVCMOS25" chip_pin = "E33" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_RXER is				"E33"
	// synthesis attribute IOSTANDARD of			PHY_RXER is				"LVCMOS25"
	input	[7:0]			PHY_RXD					/* synthesis xc_loc = "F33,D34,C34,D32,C32,C33,B33,A33" xc_padtype = "IBUF_LVCMOS25" chip_pin = "F33,D34,C34,D32,C32,C33,B33,A33" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_RXD is				"F33,D34,C34,D32,C32,C33,B33,A33"
	// synthesis attribute IOSTANDARD of			PHY_RXD is				"LVCMOS25"

	output					PHY_TXC_GTXCLK			/* synthesis xc_loc = "J16" xc_padtype = "OBUF_LVDCI_33" chip_pin = "J16" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					PHY_TXC_GTXCLK is		"J16"
	// synthesis attribute IOSTANDARD of			PHY_TXC_GTXCLK is		"LVDCI_33"
	// synthesis attribute PERIOD of				PHY_TXC_GTXCLK is		"125 MHz"
	input					PHY_TXCLK				/* synthesis xc_loc = "K17" xc_padtype = "IBUF_LVCMOS25" chip_pin = "K17" altera_attribute="-name IO_STANDARD LVCMOS25" */;
	// synthesis attribute LOC of					PHY_TXCLK is			"K17"
	// synthesis attribute IOSTANDARD of			PHY_TXCLK is			"LVCMOS25"
	// synthesis attribute PERIOD of				PHY_TXCLK is			"25 MHz"
	output					PHY_TXCTL_TXEN			/* synthesis xc_loc = "AJ10" xc_padtype = "OBUF_LVDCI_33" chip_pin = "AJ10" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					PHY_TXCTL_TXEN is		"AJ10"
	// synthesis attribute IOSTANDARD of			PHY_TXCTL_TXEN is		"LVDCI_33"
	output					PHY_TXER				/* synthesis xc_loc = "AJ9" xc_padtype = "OBUF_LVDCI_33" chip_pin = "AJ9" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					PHY_TXER is				"AJ9"
	// synthesis attribute IOSTANDARD of			PHY_TXER is				"LVDCI_33"
	output	[7:0]			PHY_TXD					/* synthesis xc_loc = "AG11,AG10,AH8,AG8,AH10,AH9,AE11,AF11" xc_padtype = "OBUF_LVDCI_33" chip_pin = "AG11,AG10,AH8,AG8,AH10,AH9,AE11,AF11" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					PHY_TXD is				"AG11,AG10,AH8,AG8,AH10,AH9,AE11,AF11"
	// synthesis attribute IOSTANDARD of			PHY_TXD is				"LVDCI_33"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Bank 116 GTPs: Small Form-Factor Pluggable & SMA
	//--------------------------------------------------------------------------
	input					CLKBUF_Q0_N				/* synthesis xc_loc = "H3" chip_pin = "H3" */;
	// synthesis attribute LOC of					CLKBUF_Q0_N is			"H3"
	input					CLKBUF_Q0_P				/* synthesis xc_loc = "H4" chip_pin = "H4" */;
	// synthesis attribute LOC of					CLKBUF_Q0_P is			"H4"

	input					SFP_RX_N				/* synthesis xc_loc = "H1" chip_pin = "H1" */;
	// synthesis attribute LOC of					SFP_RX_N is				"H1"
	input					SFP_RX_P				/* synthesis xc_loc = "G1" chip_pin = "G1" */;
	// synthesis attribute LOC of					SFP_RX_P is				"G1"
	output					SFP_TX_DISABLE_FPGA		/* synthesis xc_loc = "K24" chip_pin = "K24" */;
	// synthesis attribute LOC of					SFP_TX_DISABLE_FPGA is	"K24"
	output					SFP_TX_N				/* synthesis xc_loc = "G2" chip_pin = "G2" */;
	// synthesis attribute LOC of					SFP_TX_N is				"G2"
	output					SFP_TX_P				/* synthesis xc_loc = "F2" chip_pin = "F2" */;
	// synthesis attribute LOC of					SFP_TX_P is				"F2"
	inout					I2C_SCL_SFP				/* synthesis xc_loc = "R26" chip_pin = "R26" */;
	// synthesis attribute LOC of					I2C_SCL_SFP is			"R26"
	inout					I2C_SDA_SFP				/* synthesis xc_loc = "U28" chip_pin = "U28" */;
	// synthesis attribute LOC of					I2C_SDA_SFP is			"U28"

	input					SMA_RX_N				/* synthesis xc_loc = "J1" chip_pin = "J1" */;
	// synthesis attribute LOC of					SMA_RX_N is				"J1"
	input					SMA_RX_P				/* synthesis xc_loc = "K1" chip_pin = "K1" */;
	// synthesis attribute LOC of					SMA_RX_P is				"K1"
	output					SMA_TX_N				/* synthesis xc_loc = "K2" chip_pin = "K2" */;
	// synthesis attribute LOC of					SMA_TX_N is				"K2"
	output					SMA_TX_P				/* synthesis xc_loc = "L2" chip_pin = "L2" */;
	// synthesis attribute LOC of					SMA_TX_P is				"L2"
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Bank 112 GTPs: SGMII & Loopback
	//--------------------------------------------------------------------------
	input					SGMIICLK_QO_N			/* synthesis xc_loc = "P3" chip_pin = "P3" */;
	// synthesis attribute LOC of					SGMIICLK_QO_N is		"P3"
	input					SGMIICLK_QO_P			/* synthesis xc_loc = "P4" chip_pin = "P4" */;
	// synthesis attribute LOC of					SGMIICLK_QO_P is		"P4"
	
	input					SGMII_RX_N				/* synthesis xc_loc = "P1" chip_pin = "P1" */;
	// synthesis attribute LOC of					SGMII_RX_N is			"P1"
	input					SGMII_RX_P				/* synthesis xc_loc = "N1" chip_pin = "N1" */;
	// synthesis attribute LOC of					SGMII_RX_P is			"N1"
	output					SGMII_TX_N				/* synthesis xc_loc = "N2" chip_pin = "N2" */;
	// synthesis attribute LOC of					SGMII_TX_N is			"N2"
	output					SGMII_TX_P				/* synthesis xc_loc = "M2" chip_pin = "M2" */;
	// synthesis attribute LOC of					SGMII_TX_P is			"M2"

	input					LOOPBK_112_RX_N			/* synthesis xc_loc = "R1" chip_pin = "R1" */;
	// synthesis attribute LOC of					LOOPBK_112_RX_N is		"R1"
	output					LOOPBK_112_TX_N			/* synthesis xc_loc = "T2" chip_pin = "T2" */;
	// synthesis attribute LOC of					LOOPBK_112_TX_N is		"T2"
	input					LOOPBK_112_RX_P			/* synthesis xc_loc = "T1" chip_pin = "T1" */;
	// synthesis attribute LOC of					LOOPBK_112_RX_P is		"T1"
	output					LOOPBK_112_TX_P			/* synthesis xc_loc = "U2" chip_pin = "U2" */;
	// synthesis attribute LOC of					LOOPBK_112_TX_P is		"U2"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	Bank 114 GTPs: SATA Connectors
	//--------------------------------------------------------------------------
	input					SATACLK_QO_N			/* synthesis xc_loc = "Y3" chip_pin = "Y3" */;
	// synthesis attribute LOC of					SATACLK_QO_N is			"Y3"
	input					SATACLK_QO_P			/* synthesis xc_loc = "Y4" chip_pin = "Y4" */;
	// synthesis attribute LOC of					SATACLK_QO_P is			"Y4"
	
	input	[2:1]			SATA_RX_N				/* synthesis xc_loc = "AA1,Y1" chip_pin = "AA1,Y1" */;
	// synthesis attribute LOC of					SATA_RX_N is			"AA1,Y1"
	input	[2:1]			SATA_RX_P				/* synthesis xc_loc = "AB1,W1" chip_pin = "AB1,W1" */;
	// synthesis attribute LOC of					SATA_RX_P is			"AB1,W1"
	output	[2:1]			SATA_TX_N				/* synthesis xc_loc = "AB2,W2" chip_pin = "AB2,W2" */;
	// synthesis attribute LOC of					SATA_TX_N is			"AB2,W2"
	output	[2:1]			SATA_TX_P				/* synthesis xc_loc = "AC2,V2" chip_pin = "AC2,V2" */;
	// synthesis attribute LOC of					SATA_TX_P is			"AC2,V2"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	ZBT SRAM & Linear Flash Memory
	//--------------------------------------------------------------------------
	output					SRAM_CLK				/* synthesis xc_loc = "G8" xc_padtype = "OBUF_LVCMOS33_F_12" chip_pin = "G8" altera_attribute="-name IO_STANDARD LVCMOS33_F_12" */;
	// synthesis attribute LOC of					SRAM_CLK is				"G8"
	// synthesis attribute IOSTANDARD of			SRAM_CLK is				"LVCMOS33"
	// synthesis attribute SLEW of					SRAM_CLK is				"FAST";
	// synthesis attribute DRIVE of					SRAM_CLK is				"12";
	output					SRAM_CLK_FB				/* synthesis xc_loc = "AG21" xc_padtype = "OBUF_LVCMOS33" chip_pin = "AG21" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SRAM_CLK_FB is			"AG21"
	// synthesis attribute IOSTANDARD of			SRAM_CLK_FB is			"LVCMOS33"
	output					SRAM_CS_B				/* synthesis xc_loc = "J10" xc_padtype = "OBUF_LVDCI_33" chip_pin = "J10" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_CS_B is			"J10"
	// synthesis attribute IOSTANDARD of			SRAM_CS_B is			"LVDCI_33"
	output					SRAM_ADV_LD_B			/* synthesis xc_loc = "H8" xc_padtype = "OBUF_LVDCI_33" chip_pin = "H8" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_ADV_LD_B is		"H8"
	// synthesis attribute IOSTANDARD of			SRAM_ADV_LD_B is		"LVDCI_33"
	
	output					SRAM_FLASH_WE_B			/* synthesis xc_loc = "AF20" xc_padtype = "OBUF_LVDCI_33_F_20" chip_pin = "AF20" altera_attribute="-name IO_STANDARD LVDCI_33_F_20" */;
	// synthesis attribute LOC of					SRAM_FLASH_WE_B is		"AF20"
	// synthesis attribute IOSTANDARD of			SRAM_FLASH_WE_B is		"LVDCI_33"
	// synthesis attribute SLEW of					SRAM_FLASH_WE_B is		"FAST"
	// synthesis attribute DRIVE of					SRAM_FLASH_WE_B is		"20"
	output					SRAM_MODE				/* synthesis xc_loc = "A13" xc_padtype = "OBUF_LVDCI_33" chip_pin = "A13" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_MODE is			"A13"
	// synthesis attribute IOSTANDARD of			SRAM_MODE is			"LVDCI_33"
	output					SRAM_OE_B				/* synthesis xc_loc = "B12" xc_padtype = "OBUF_LVDCI_33" chip_pin = "B12" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_OE_B is			"B12"
	// synthesis attribute IOSTANDARD of			SRAM_OE_B is			"LVDCI_33"

	output					FLASH_ADV_B				/* synthesis xc_loc = "F13" chip_pin = "F13" */;
	// synthesis attribute LOC of					FLASH_ADV_B is			"F13"
	output					FLASH_AUDIO_RESET_B		/* synthesis xc_loc = "AG17" chip_pin = "AG17" */;
	// synthesis attribute LOC of					FLASH_AUDIO_RESET_B is	"AG17"
	output					FLASH_CE_B				/* synthesis xc_loc = "AE14" xc_padtype = "OBUF_LVCMOS33" chip_pin = "AE14" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FLASH_CE_B is			"AE14"
	// synthesis attribute IOSTANDARD of			FLASH_CE_B is			"LVCMOS33"
	output					FLASH_CLK				/* synthesis xc_loc = "N9" chip_pin = "N9" */;
	// synthesis attribute LOC of					FLASH_CLK is			"N9"
	output					FLASH_OE_B				/* synthesis xc_loc = "AF14" xc_padtype = "OBUF_LVCMOS33" chip_pin = "AF14" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					FLASH_OE_B is			"AF14"
	// synthesis attribute IOSTANDARD of			FLASH_OE_B is			"LVCMOS33"
	output					FLASH_WAIT				/* synthesis xc_loc = "G13" chip_pin = "G13" */;
	// synthesis attribute LOC of					FLASH_WAIT is			"G13"
	
	output	[3:0]			SRAM_BW					/* synthesis xc_loc = "K11,J11,D11,D10" xc_padtype = "OBUF_LVDCI_33" chip_pin = "K11,J11,D11,D10" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_BW is				"K11,J11,D11,D10"
	// synthesis attribute IOSTANDARD of			SRAM_BW is				"LVDCI_33"

	output	[3:0]			SRAM_DQP				/* synthesis xc_loc = "H9,H10,C12,D12" xc_padtype = "OBUF_LVDCI_33" chip_pin = "H9,H10,C12,D12" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_DQP is				"H9,H10,C12,D12"
	// synthesis attribute IOSTANDARD of			SRAM_DQP is				"LVDCI_33"

	output	[21:0]			SRAM_FLASH_A			/* synthesis xc_loc = "AE22,AE23,L21,L20,L15,L16,J22,K21,K16,J15,G22,H22,L14,K14,K23,K22,J12,H12,G23,H23,K13,K12" xc_padtype = "OBUF_LVCMOS33_F_8" chip_pin = "AE22,AE23,L21,L20,L15,L16,J22,K21,K16,J15,G22,H22,L14,K14,K23,K22,J12,H12,G23,H23,K13,K12" altera_attribute="-name IO_STANDARD LVCMOS33_F_8" */;
	// synthesis attribute LOC of					SRAM_FLASH_A is			"AE22,AE23,L21,L20,L15,L16,J22,K21,K16,J15,G22,H22,L14,K14,K23,K22,J12,H12,G23,H23,K13,K12"
	// synthesis attribute IOSTANDARD of			SRAM_FLASH_A is			"LVCMOS33"
	// synthesis attribute SLEW of					SRAM_FLASH_A is			"FAST"
	// synthesis attribute DRIVE of					SRAM_FLASH_A is			"8"
	inout	[15:0]			SRAM_FLASH_D			/* synthesis xc_loc = "AG22,AH22,AH12,AG13,AH20,AH19,AH14,AH13,AF15,AE16,AE21,AD20,AF16,AE17,AE19,AD19" xc_padtype = "IOBUF_LVCMOS33_F_12" xc_pulldown = 1 chip_pin = "AG22,AH22,AH12,AG13,AH20,AH19,AH14,AH13,AF15,AE16,AE21,AD20,AF16,AE17,AE19,AD19" altera_attribute="-name IO_STANDARD LVCMOS33_F_12" */;
	// synthesis attribute LOC of					SRAM_FLASH_D is			"AG22,AH22,AH12,AG13,AH20,AH19,AH14,AH13,AF15,AE16,AE21,AD20,AF16,AE17,AE19,AD19"
	// synthesis attribute IOSTANDARD of			SRAM_FLASH_D is			"LVCMOS33"
	// synthesis attribute SLEW of					SRAM_FLASH_D is			"FAST"
	// synthesis attribute DRIVE of					SRAM_FLASH_D is			"12"
	inout	[31:16]			SRAM_D					/* synthesis xc_loc = "J9,K8,K9,B13,C13,G11,G12,M8,L8,F11,E11,M10,L9,E12,E13,N10" xc_padtype = "IOBUF_LVDCI_33" xc_pulldown = 1 chip_pin = "J9,K8,K9,B13,C13,G11,G12,M8,L8,F11,E11,M10,L9,E12,E13,N10" altera_attribute="-name IO_STANDARD LVDCI_33" */;
	// synthesis attribute LOC of					SRAM_D is				"J9,K8,K9,B13,C13,G11,G12,M8,L8,F11,E11,M10,L9,E12,E13,N10"
	// synthesis attribute IOSTANDARD of			SRAM_D is				"LVDCI_33"
	
	`ifdef PULL
		generate for (i = 0; i < 32; i = i + 1) begin:SRAM_PULLDOWN
			pulldown(SRAM_D[i]);
		end endgenerate
	`endif
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	System ACE & Cypress USB
	//--------------------------------------------------------------------------
	output	[6:0]			SYSACE_MPA				/* synthesis xc_loc = "L6,M6,R6,P5,N5,N7,G5" xc_padtype="OBUF_LVCMOS33" chip_pin = "L6,M6,R6,P5,N5,N7,G5" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPA is			"L6,M6,R6,P5,N5,N7,G5"
	// synthesis attribute IOSTANDARD of			SYSACE_MPA is			"LVCMOS33"

	inout					SYSACE_MPBRDY			/* synthesis xc_loc = "H5" xc_padtype="IOBUF_LVCMOS33" chip_pin = "H5" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPBRDY is		"H5"
	// synthesis attribute IOSTANDARD of			SYSACE_MPBRDY is		"LVCMOS33"
	output					SYSACE_MPCE				/* synthesis xc_loc = "M5" xc_padtype="OBUF_LVCMOS33" chip_pin = "M5" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPCE is			"M5"
	// synthesis attribute IOSTANDARD of			SYSACE_MPCE is			"LVCMOS33"
	input					SYSACE_MPIRQ			/* synthesis xc_loc = "M7" xc_padtype="IBUF_LVCMOS33" chip_pin = "M7" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPIRQ is			"M7"
	// synthesis attribute IOSTANDARD of			SYSACE_MPIRQ is			"LVCMOS33"
	output					SYSACE_MPOE_USB_RD_B	/* synthesis xc_loc = "N8" xc_padtype="OBUF_LVCMOS33" chip_pin = "N8" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPOE_USB_RD_B is	"N8"
	// synthesis attribute IOSTANDARD of			SYSACE_MPOE_USB_RD_B is	"LVCMOS33"
	output					SYSACE_MPWE_USB_WR_B	/* synthesis xc_loc = "R9" xc_padtype="OBUF_LVCMOS33" chip_pin = "R9" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_MPWE_USB_WR_B is	"R9"
	// synthesis attribute IOSTANDARD of			SYSACE_MPWE_USB_WR_B is	"LVCMOS33"

	inout	[15:0]			SYSACE_USB_D			/* synthesis xc_loc = "J6,K7,T6,J5,K6,L4,L5,R8,P6,P7,U7,R7,H7,J7,T8,P9" xc_padtype="IOBUF_LVCMOS33" chip_pin = "J6,K7,T6,J5,K6,L4,L5,R8,P6,P7,U7,R7,H7,J7,T8,P9" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					SYSACE_USB_D is			"J6,K7,T6,J5,K6,L4,L5,R8,P6,P7,U7,R7,H7,J7,T8,P9"
	// synthesis attribute IOSTANDARD of			SYSACE_USB_D is			"LVCMOS33"

	output	[1:0]			USB_A					/* synthesis xc_loc = "N5,N7" xc_padtype="OBUF_LVCMOS33" chip_pin = "N5,N7" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					USB_A is				"N5,N7"
	// synthesis attribute IOSTANDARD of			USB_A is				"LVCMOS33"
	output					USB_CS_B				/* synthesis xc_loc = "P10" xc_padtype="OBUF_LVCMOS33" chip_pin = "P10" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					USB_CS_B is				"P10"
	// synthesis attribute IOSTANDARD of			USB_CS_B is				"LVCMOS33"
	input					USB_INT					/* synthesis xc_loc = "F5" xc_padtype="IBUF_LVCMOS33" chip_pin = "F5" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					USB_INT is				"F5"
	// synthesis attribute IOSTANDARD of			USB_INT is				"LVCMOS33"
	output					USB_RESET_B				/* synthesis xc_loc = "R11" xc_padtype="OBUF_LVCMOS33" chip_pin = "R11" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					USB_RESET_B is			"R11"
	// synthesis attribute IOSTANDARD of			USB_RESET_B is			"LVCMOS33"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	Tracing
	//--------------------------------------------------------------------------
	inout					TRC_CLK					/* synthesis xc_loc = "AD9" chip_pin = "AD9" */;
	// synthesis attribute LOC of					TRC_CLK is				"AD9"
	inout					TRC_TS1E				/* synthesis xc_loc = "AK9" chip_pin = "AK9" */;
	// synthesis attribute LOC of					TRC_TS1E is				"AK9"
	inout					TRC_TS1O				/* synthesis xc_loc = "AF10" chip_pin = "AF10" */;
	// synthesis attribute LOC of					TRC_TS1O is				"AF10"
	inout					TRC_TS2E				/* synthesis xc_loc = "AK8" chip_pin = "AK8" */;
	// synthesis attribute LOC of					TRC_TS2E is				"AK8"
	inout					TRC_TS2O				/* synthesis xc_loc = "AF9" chip_pin = "AF9" */;
	// synthesis attribute LOC of					TRC_TS2O is				"AF9"
	inout					TRC_TS3					/* synthesis xc_loc = "AJ11" chip_pin = "AJ11" */;
	// synthesis attribute LOC of					TRC_TS3 is				"AJ11"
	inout					TRC_TS4					/* synthesis xc_loc = "AK11" chip_pin = "AK11" */;
	// synthesis attribute LOC of					TRC_TS4 is				"AK11"
	inout					TRC_TS5					/* synthesis xc_loc = "AD11" chip_pin = "AD11" */;
	// synthesis attribute LOC of					TRC_TS5 is				"AD11"
	inout					TRC_TS6					/* synthesis xc_loc = "AD10" chip_pin = "AD10" */;
	// synthesis attribute LOC of					TRC_TS6 is				"AD10"
	//--------------------------------------------------------------------------

	//--------------------------------------------------------------------------
	//	VGA (Input)
	//--------------------------------------------------------------------------
	input	[7:0]			VGA_IN_BLUE				/* synthesis xc_loc = "AD7,AC7,AB5,AA5,AB7,AB6,AC5,AC4" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AD7,AC7,AB5,AA5,AB7,AB6,AC5,AC4" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_BLUE is			"AD7,AC7,AB5,AA5,AB7,AB6,AC5,AC4"
	// synthesis attribute IOSTANDARD of			VGA_IN_BLUE is			"LVCMOS33"
	input	[7:0]			VGA_IN_GREEN			/* synthesis xc_loc = "AE6,AD6,Y7,AA6,AD5,AD4,Y9,Y8" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AE6,AD6,Y7,AA6,AD5,AD4,Y9,Y8" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_GREEN is			"AE6,AD6,Y7,AA6,AD5,AD4,Y9,Y8"
	// synthesis attribute IOSTANDARD of			VGA_IN_GREEN is			"LVCMOS33"
	input	[7:0]			VGA_IN_RED				/* synthesis xc_loc = "W11,Y11,AG6,AH5,V7,W7,AF5,AG5" xc_padtype = "IBUF_LVCMOS33" chip_pin = "W11,Y11,AG6,AH5,V7,W7,AF5,AG5" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_RED is			"W11,Y11,AG6,AH5,V7,W7,AF5,AG5"
	// synthesis attribute IOSTANDARD of			VGA_IN_RED is			"LVCMOS33"

	input					VGA_IN_CLAMP			/* synthesis xc_loc = "AH7" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AH7" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_CLAMP is			"AH7"
	// synthesis attribute IOSTANDARD of			VGA_IN_CLAMP is			"LVCMOS33"
	input					VGA_IN_COAST			/* synthesis xc_loc = "AG7" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AG7" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_COAST is			"AG7"
	// synthesis attribute IOSTANDARD of			VGA_IN_COAST is			"LVCMOS33"
	input					VGA_IN_DATA_CLK			/* synthesis xc_loc = "AH18" chip_pin = "AH18" */;
	// synthesis attribute LOC of					VGA_IN_DATA_CLK is		"AH18"
	input					VGA_IN_HSOUT			/* synthesis xc_loc = "AE7" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AE7" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_HSOUT is			"AE7"
	// synthesis attribute IOSTANDARD of			VGA_IN_HSOUT is			"LVCMOS33"
	input					VGA_IN_ODD_EVEN_B		/* synthesis xc_loc = "W6" xc_padtype = "IBUF_LVCMOS33" chip_pin = "W6" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_ODD_EVEN_B is	"W6"
	// synthesis attribute IOSTANDARD of			VGA_IN_ODD_EVEN_B is	"LVCMOS33"
	input					VGA_IN_SOGOUT			/* synthesis xc_loc = "AF6" xc_padtype = "IBUF_LVCMOS33" chip_pin = "AF6" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_SOGOUT is		"AF6"
	// synthesis attribute IOSTANDARD of			VGA_IN_SOGOUT is		"LVCMOS33"
	input					VGA_IN_VSOUT			/* synthesis xc_loc = "Y6" xc_padtype = "IBUF_LVCMOS33" chip_pin = "Y6" altera_attribute="-name IO_STANDARD LVCMOS33" */;
	// synthesis attribute LOC of					VGA_IN_VSOUT is			"Y6"
	// synthesis attribute IOSTANDARD of			VGA_IN_VSOUT is			"LVCMOS33"
	//--------------------------------------------------------------------------
	
	
	wire						Clock;
	BUFG						(.I(CLK_33MHZ_FPGA),	.O(Clock));
	
	wire						Reset;
	wire						Up,	Down;
	wire	[2:0]				State;
	wire	[2:0]				DebugState;
	
	wire						ResetLock;
	wire						Enter;
	wire						Open;
	wire	[3:0]				Combination;
	
	//--------------------------------------------------------------------------
	//	Parameters
	//--------------------------------------------------------------------------
	parameter					ClockFreq =				33000000;
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Parse input from buttons
	//--------------------------------------------------------------------------
	ButtonParse	#(
			.Width(				1),
			.DebWidth(			`log2(ClockFreq / 100)),
			.EdgeOutWidth(		1)
		) resetParse	(	
			.Clock(				Clock),
			.Reset(				1'b0),
			.Enable(			1'b1),
			.In(				FPGA_CPU_RESET_B),
			.Out(				Reset));
			
	ButtonParse	#(
			.Width(				1),
			.DebWidth(			`log2(ClockFreq / 100)),
			.EdgeOutWidth(		1)
		) lockEnterParse	(	
			.Clock(				Clock),
			.Reset(				1'b0),
			.Enable(			1'b1),
			.In(				FPGA_ROTARY_PUSH),
			.Out(				Enter));
	
	ButtonParse	#(
			.Width(				1),
			.DebWidth(			`log2(ClockFreq / 100)),
			.EdgeOutWidth(		1)
		) lockResetParse	(	
			.Clock(				Clock),
			.Reset(				1'b0),
			.Enable(			1'b1),
			.In(				GPIO_COMPSW[0]),
			.Out(				ResetLock));
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Lab 3
	//--------------------------------------------------------------------------
	RotaryEncoder	rotaryEncoder(
			.Clock(				Clock),
			.A(					FPGA_ROTARY_INCA),
			.B(					FPGA_ROTARY_INCB),
			.Up(				Up),
			.Down(				Down));
	
	Lab3Counter	lab3Counter(
			.Clock(				Clock),
			.Reset(				Reset),
			.Increment(			Up),
			.Decrement(			Down),
			.Count(				Combination)
	);
	
	Lab3Lock	lab3Lock(
			.Clock(				Clock),
			.Reset(				Reset),
			.DebugState(		DebugState),
			.ResetLock(			ResetLock),
			.Enter(				Enter),
			.Combination(		Combination),
			.State(				State),
			.Open(				Open));
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Output Logic
	//--------------------------------------------------------------------------
	assign	DebugState		=	GPIO_DIP[2:0];
	
	assign	GPIO_LED[3:0]	=	Combination;	// Combination digit is displayed on the left 4 bits (in reverse order).
	assign	GPIO_LED[7:5]	=	State;
	assign	GPIO_COMPLED	=	{5{Open}};		// The LEDs on the compass buttons light up when the lock is open.
	//--------------------------------------------------------------------------
	
endmodule
//------------------------------------------------------------------------------